@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.0"
+#define HOST_OS "freebsd4.2"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.0"
+#define HOST_OS_VERSION "4.2"
 #define HOST_ARCH "i386"
-#define HOST_NAME "elk.mcl.cs.columbia.edu"
+#define HOST_NAME "dummy.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Apr  2 19:56:57 EST 1980"
+#define CONFIG_DATE "Thu Dec 14 12:28:49 EST 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.5s3"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.0.5s3"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "4.0"
+#define HOST_HEADER_VERSION "4.2"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -32,6 +32,7 @@
 #define HAVE_GETDOMAINNAME 1
 #define HAVE_GETDTABLESIZE 1
 #define HAVE_GETHOSTNAME 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
@@ -170,7 +171,9 @@
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
+#define HAVE_LIBGEN_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
@@ -252,11 +255,17 @@
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -307,12 +316,15 @@
 #define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_KERB 0x400
 #define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
 #define MNT2_NFS_OPT_NQNFS 0x100
+#define MNT2_NFS_OPT_RDIRPLUS 0x10000
 #define MNT2_NFS_OPT_READAHEAD 0x2000
+#define MNT2_NFS_OPT_READDIRSIZE 0x20000
 #define MNT2_NFS_OPT_RESVPORT 0x8000
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
@@ -323,4 +335,5 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
